@@ -1,7 +1,7 @@
 package Getopt::Long::Util;
 
-our $DATE = '2016-10-27'; # DATE
-our $VERSION = '0.87'; # VERSION
+our $DATE = '2016-10-30'; # DATE
+our $VERSION = '0.88'; # VERSION
 
 use 5.010001;
 use strict;
@@ -13,6 +13,7 @@ our @EXPORT_OK = qw(
                        parse_getopt_long_opt_spec
                        humanize_getopt_long_opt_spec
                        detect_getopt_long_script
+                       gen_getopt_long_spec_from_getopt_std_spec
                );
 
 our %SPEC;
@@ -202,7 +203,7 @@ _
             cmdline_aliases => {f=>{}},
         },
         string => {
-            summary => 'Path to file to be checked',
+            summary => 'String to be checked',
             schema => 'buf*',
         },
         include_noexec => {
@@ -293,6 +294,48 @@ sub detect_getopt_long_script {
     [200, "OK", $yesno, {"func.reason"=>$reason, %extrameta}];
 }
 
+$SPEC{gen_getopt_long_spec_from_getopt_std_spec} = {
+    v => 1.1,
+    summary => 'Generate Getopt::Long spec from Getopt::Std spec',
+    args => {
+        spec => {
+            summary => 'Getopt::Std spec string',
+            schema => 'str*',
+            req => 1,
+            pos => 0,
+        },
+        is_getopt => {
+            summary => 'Whether to assume spec is for getopt() or getopts()',
+            description => <<'_',
+
+By default spec is assumed to be for getopts() instead of getopt(). This means
+that for a spec like `abc:`, `a` and `b` don't take argument while `c` does. But
+if `is_getopt` is true, the meaning of `:` is reversed: `a` and `b` take
+arguments while `c` doesn't.
+
+_
+            schema => 'bool',
+        },
+    },
+    result_naked => 1,
+    result => {
+        schema => 'hash*',
+    },
+};
+sub gen_getopt_long_spec_from_getopt_std_spec {
+    my %args = @_;
+
+    my $is_getopt = $args{is_getopt};
+    my $spec = {};
+
+    while ($args{spec} =~ /(.)(:?)/g) {
+        $spec->{$1 . ($is_getopt ? ($2 ? "" : "=s") : ($2 ? "=s" : ""))} =
+            sub {};
+    }
+
+    $spec;
+}
+
 # ABSTRACT: Utilities for Getopt::Long
 
 __END__
@@ -307,7 +350,7 @@ Getopt::Long::Util - Utilities for Getopt::Long
 
 =head1 VERSION
 
-This document describes version 0.87 of Getopt::Long::Util (from Perl distribution Getopt-Long-Util), released on 2016-10-27.
+This document describes version 0.88 of Getopt::Long::Util (from Perl distribution Getopt-Long-Util), released on 2016-10-30.
 
 =head1 FUNCTIONS
 
@@ -348,7 +391,7 @@ Include scripts that do not have +x mode bit set.
 
 =item * B<string> => I<buf>
 
-Path to file to be checked.
+String to be checked.
 
 =back
 
@@ -364,6 +407,34 @@ that contains extra information.
 Return value:  (any)
 
 
+=head2 gen_getopt_long_spec_from_getopt_std_spec(%args) -> hash
+
+Generate Getopt::Long spec from Getopt::Std spec.
+
+This function is not exported by default, but exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<is_getopt> => I<bool>
+
+Whether to assume spec is for getopt() or getopts().
+
+By default spec is assumed to be for getopts() instead of getopt(). This means
+that for a spec like C<abc:>, C<a> and C<b> don't take argument while C<c> does. But
+if C<is_getopt> is true, the meaning of C<:> is reversed: C<a> and C<b> take
+arguments while C<c> doesn't.
+
+=item * B<spec>* => I<str>
+
+Getopt::Std spec string.
+
+=back
+
+Return value:  (hash)
+
+
 =head2 humanize_getopt_long_opt_spec($optspec) -> str
 
 Convert L<Getopt::Long> option specification like C<help|h|?> or C<--foo=s> or
